@@ -89,6 +89,7 @@ FILE*           dumper_fp = 0;
 time_t          dumpstart;
 size_t          msgcount      = 0;
 size_t          capturedbytes = 0;
+size_t          pkthdr_caplen = 0;
 char *          dumpname, *dumpnamepart;
 char*           bpft;
 unsigned        dns_port       = DNS_PORT;
@@ -143,8 +144,8 @@ int main(int argc, char* argv[])
             struct tm tm;
             gmtime_r(&start_time, &tm);
             strftime(when, sizeof when, "%F %T", &tm);
-            fprintf(stderr, "Sleeping for %d seconds until %s UTC\n",
-                (int)(start_time - now.tv_sec), when);
+            fprintf(stderr, "Sleeping for %" PRI_tv_sec " seconds until %s UTC\n",
+                start_time - now.tv_sec, when);
             sleep(start_time - now.tv_sec);
             fprintf(stderr, "Awake.\n");
         }
