@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2020, OARC, Inc.
+ * Copyright (c) 2016-2025 OARC, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,14 +37,17 @@
 #ifndef __dnscap_dumper_h
 #define __dnscap_dumper_h
 
+void set_output_pkt(u_char* pkt, const unsigned olen);
+
 void output(const char* descr, iaddr from, iaddr to, uint8_t proto, unsigned flags,
     unsigned sport, unsigned dport, my_bpftimeval ts,
-    const u_char* pkt_copy, const unsigned olen,
-    const u_char* payload, const unsigned payloadlen);
+    u_char* pkt_copy, const unsigned olen,
+    u_char* payload, const unsigned payloadlen);
 
 int dumper_open(my_bpftimeval ts);
 int dumper_close(my_bpftimeval ts);
 
+void           dnscap_dump_open_gz(const char* path, FILE** fp);
 pcap_dumper_t* dnscap_pcap_dump_open(pcap_t* pcap, const char* path);
 
 #endif /* __dnscap_dumper_h */
